@@ -1,4 +1,4 @@
-#ifndef C_EVENTLOOP_H
+#if !defined(C_EVENTLOOP_H)
 #define C_EVENTLOOP_H
 
 void eventloop_register(duk_context *ctx);
